<?php
$page_title = "创建账户";
include_once('site_config.php');
include_once('template/base_site_head.php');
?>
    <!-- メインエリア -->
<wrapper class="mymain_container">
	<section class="container page-container">
		<div class="form_information">
			<div class="number-list">
	            <ul class="num_ul">
	                <li class="f_1 done"><div class="circle">1</div><div class="line"></div></li><!--
	                --><li class="active f_2"><div class="circle">2</div><div class="line"></div></li><!--
	                --><li class="f_3"><div class="circle">3</div><div class="line"></div></li><!--
	                --><li class="f_4"><div class="circle">4</div><div class="line"></div></li><!--
	                --><li class="f_5"><div class="circle">5</div></li>
	            </ul>
	        </div>

		<form id="acForm" action="" method="post" class="form_list active">
		<?php $this -> dispMessagesCommon(); ?>
	        	<div class="cont_steps s_step">
	        		<div class="field_list">
	        			<div class="limit_width">
	        				<label class="title_name"><?php echo $page_title; ?></label>
			        		<p>
			        			请填下以下信息
			        		</p>
			        		<div class="cus_form">
			        			<div class="table_form table_form_list">
				        			<div class="form_elem ">
				        				<label class="title_txt">名<span id="required" class="required">*</span><br><span>请输入贵司法人代表名字的英文拼写，只限字母。（例：xiao ming）</span></label>
				        				<input type="text" name="first_name" class="verify_input" value="<?php $this -> echoFirstName(); ?>" /><i class="fa"></i>
				        			</div>
				        			<div class="form_elem ">
				        				<label class="title_txt">姓<span id="required" class="required">*</span><br><span>请输入贵司法人代表姓氏的英文拼写，只限字母。（例：AtoZ^%-@0~9!）</span></label>
				        				<input type="text" name="last_name" class="verify_input" value="<?php $this -> echoLastName(); ?>" /><i class="fa"></i>
				        			</div>
				        			<div class="form_elem ">
				        				<label class="title_txt">公司名称<span id="required" class="required">*</span></label>
				        				<input type="text" name="name" value="<?php $this -> echoName(); ?>" class="verify_input"><i class="fa"></i>
				        			</div>
				        			<div class="form_elem ">
				        				<label class="title_txt">联系电话<span id="required" class="required">*</span></label>
				        				<input type="tel" name="tel" value="<?php $this -> echoTel(); ?>" class="verify_input"><i class="fa"></i>
				        			</div>
				        			<div class="form_elem ">
				        				<label class="title_txt">法人代表出生日期</label>
				        	<select name="birth_year" id="birth_year" class="select">
								<option>--年--</option>
								<?php $this -> dispYear(); ?>
							</select>
							<select name="birth_month" id="birth_month" class="select">
								<option value="--MM--">--月--</option>
								<?php $this -> dispMonth(); ?>
							</select>
							<select name="birth_day" id="birth_day" class="select">
								<option>--日--</option>
								<?php $this -> dispDay(); ?>
							</select>
				        			</div>
				        			<div class="form_elem ">
				        				<label class="title_txt">邮箱地址</label>
				        				<?php $this -> echoEmail(); ?><i class="fa"></i>
				        			</div>
				        			<div class="form_elem verify_password">
				        				<label class="title_txt">密码<span id="required" class="required">*</span><br><span>密码长度需为8-35位数字字母组合,字母区分大小写。(例: Abcdefg1)</span></label>
				        				<input type="password" name="password" class="verify_input" value="" /><i class="fa"></i>
				        			</div>
				        			<div class="form_elem verify_password2">
				        				<label class="title_txt">再次输入<span id="required" class="required">*</span><br><span>请再次输入密码。</span></label>
				        				<input type="password" name="password_confirm" class="verify_input" value="" /><i class="fa"></i>
				        			</div>
				        			<div class="form_elem ">
				        				<label class="title_txt">国家</label>
								<select name="country" value="<?php $this -> echoEmail(); ?>" class="select">
									<option value=''>--请选择--</option>
									<?php $this -> dispCountry(); ?>
								</select>
				        			</div>
				        			<div class="form_elem ">
				        				<label class="title_txt">省<span id="required" class="required">*</span></label>
								<input type="text" name="state" value="<?php $this -> echoState(); ?>" class="verify_input">
				        			</div>
				        			<div class="form_elem ">
				        				<label class="title_txt">县/市<span id="required" class="required">*</span></label>
								<input type="text" name="city" value="<?php $this -> echoCity(); ?>" class="verify_input">
				        			</div>
				        			<div class="form_elem ">
				        				<label class="title_txt">详细地址<span id="required" class="required">*</span></label>
								<input type="text" name="address" value="<?php $this -> echoAddress(); ?>" class="verify_input">
				        			</div>
				        			<div class="form_elem ">
				        				<label class="title_txt">邮编<span id="required" class="required">*</span></label>
								<input type="text" name="zip_code" value="<?php $this -> echoZipCode(); ?>" class="verify_input">
				        			</div>
				        			<div class="form_elem ">
				        				<label class="title_txt">服务网站或品牌名称<br><span>请填写贵司的服务平台网址。</span></label>
								<input type="text" name="site_name" value="<?php $this -> echoSiteName(); ?>" class="verify_input">
				        			</div>
				        			<div class="form_elem ">
				        				<label class="title_txt">服务平台URL（或者官方网站URL）<span id="required" class="required">*</span></label>
								<input type="url" name="site_url" value="<?php $this -> echoSiteUrl(); ?>" class="verify_input">
				        			</div>

				        		</div>
			        		</div>
	        			</div>
	        			
	        		</div>
	        		<div class="event_next1 event_custom">
	        			<input type="button" id="btnConfirm" value="下一步" class="custom nxt_form">
	        		</div>

			<input type="hidden" id="type" name="type" value="" />
			<input type="hidden" id="account_type" name="account_type" value="<?php $this -> echoAccountType(); ?>" />
			<input type="hidden" id="email" name="email" value="<?php $this -> echoEmail(); ?>" />
			<input type="hidden" id="agent_code" name="agent_code" value="<?php $this -> echoAgent(); ?>" />
			</div>
		</form>

	<script src="../js/register.js"></script>
		</div>
	</section>

</wrapper>
<?php
include_once('template/base_site_foot.php');
echo $endscripts;
?>
</body>
</html>